<?php

namespace App\Http\Controllers\Admin;

use App\Helper\ImageHelper;
use App\Http\Controllers\Controller;
use App\Models\MainPageService;
use Illuminate\Http\Request;

class MainPageServiceController extends Controller
{
    public $resource = 'mainPageService';
    public $route = 'mainPageServices';

    public function __construct()
    {
        view()->share('item', $this->resource);
        view()->share('route', $this->route);
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function index()
    {
        $mainPageServices = MainPageService::query()->orderBy('created_at', 'desc')->paginate(10);
        return view('admin.crud.main-page-service._table',compact('mainPageServices'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function create()
    {
        return view('admin.crud.main-page-service._create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function store(Request $request)
    {
        $input = $request->all();
        if($request->hasFile('photo')  ) {
            $mainServicePhoto = ImageHelper::add($request->photo, null, 'photo');
            $input['photo'] = $mainServicePhoto;
            MainPageService::query()->create($input);
        }
        return redirect()->route('dashboard.mainPageServices.index')->with('success', 'Main Page Service added successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $mainPageService = MainPageService::query()->find($id);
        return view('admin.crud.main-page-service._edit',compact('mainPageService'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $mainPageService = MainPageService::query()->find($id);
        $input = $request->all();
        if($request->hasFile('photo')  ) {
            $mainServicePhoto = ImageHelper::add($request->photo, null, 'photo');
            $input['photo'] = $mainServicePhoto;
        }
        $mainPageService->update($input);
        return redirect()->route('dashboard.mainPageServices.index')->with('Main Page Service updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\RedirectResponse
     */
    public function destroy($id)
    {
        MainPageService::query()->where('id',$id)->first()->delete();
        return redirect()->route('dashboard.mainPageServices.index')->with('Main Page Service deleted successfully');
    }

    public function deleteImage(Request $request)
    {
        $mainPageService = MainPageService::query()->findOrFail($request->mainPageService_id);

        // Delete the existing identity photo
        if ($mainPageService->photo) {
            ImageHelper::delete($mainPageService->photo);
            $mainPageService->photo = 0;
            $mainPageService->save();

            return response()->json(['success' => true]);
        }

        return response()->json(['success' => false], 400);
    }
}
