<?php

namespace App\Http\Controllers\Admin;

use App\Helper\ImageHelper;
use App\Http\Controllers\Controller;
use App\Models\NewEvent;
use Illuminate\Http\Request;

class NewEventController extends Controller
{
    public $resource = 'newsEvent';
    public $route = 'newsEvents';

    public function __construct()
    {
        view()->share('item', $this->resource);
        view()->share('route', $this->route);
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function index()
    {
        $newsEvents = NewEvent::query()->orderBy('created_at', 'desc')->paginate(10);
        return view('admin.crud.news-events._table',compact('newsEvents'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function create()
    {
        return view('admin.crud.news-events._create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function store(Request $request)
    {
        $input = $request->all();
        if($request->hasFile('photo')  ) {
            $newsEventPhoto = ImageHelper::add($request->photo, null, 'photo');
            $input['photo'] = $newsEventPhoto;
            NewEvent::query()->create($input);
        }
        return redirect()->route('dashboard.newsEvents.index')->with('success', 'Slider added successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $newsEvent = NewEvent::query()->find($id);
        return view('admin.crud.news-events._edit',compact('newsEvent'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $newsEvent = NewEvent::query()->find($id);
        $input = $request->all();
        if($request->hasFile('photo')  ) {
            $newsEventPhoto = ImageHelper::add($request->photo, null, 'photo');
            $input['photo'] = $newsEventPhoto;
        }
        $newsEvent->update($input);
        return redirect()->route('dashboard.newsEvents.index')->with('Slider updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\RedirectResponse
     */
    public function destroy($id)
    {
        NewEvent::query()->where('id',$id)->first()->delete();
        return redirect()->route('dashboard.newsEvents.index')->with('Slider deleted successfully');
    }

    public function deleteImage(Request $request)
    {
        $newsEvent = NewEvent::query()->findOrFail($request->newsEvent_id);

        // Delete the existing identity photo
        if ($newsEvent->photo) {
            ImageHelper::delete($newsEvent->photo);
            $newsEvent->photo = 0;
            $newsEvent->save();

            return response()->json(['success' => true]);
        }

        return response()->json(['success' => false], 400);
    }
}
