<?php

namespace App\Http\Controllers\Admin;

use App\Helper\ImageHelper;
use App\Http\Controllers\Controller;
use App\Models\Slider;
use Illuminate\Http\Request;

class SliderController extends Controller
{

    public $resource = 'slider';
    public $route = 'sliders';

    public function __construct()
    {
        view()->share('item', $this->resource);
        view()->share('route', $this->route);
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function index()
    {
        $sliders = Slider::query()->orderBy('created_at', 'desc')->paginate(10);
        return view('admin.crud.slider._table',compact('sliders'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function create()
    {
        return view('admin.crud.slider._create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function store(Request $request)
    {
        $input = $request->all();
        if($request->hasFile('photo')  ) {
            $sliderPhoto = ImageHelper::add($request->photo, null, 'photo');
            $input['photo'] = $sliderPhoto;
            Slider::query()->create($input);
        }
        return redirect()->route('dashboard.sliders.index')->with('success', 'Slider added successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $slider = Slider::query()->find($id);
        return view('admin.crud.slider._edit',compact('slider'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $slider = Slider::query()->find($id);
        $input = $request->all();
        if($request->hasFile('photo')  ) {
            $sliderPhoto = ImageHelper::add($request->photo, null, 'photo');
            $input['photo'] = $sliderPhoto;
        }
        $slider->update($input);
        return redirect()->route('dashboard.sliders.index')->with('Slider updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\RedirectResponse
     */
    public function destroy($id)
    {
        Slider::query()->where('id',$id)->first()->delete();
        return redirect()->route('dashboard.sliders.index')->with('Slider deleted successfully');
    }

    public function deleteSliderPhoto(Request $request)
    {
        $slider = Slider::query()->findOrFail($request->slider_id);

        // Delete the existing identity photo
        if ($slider->photo) {
            ImageHelper::delete($slider->photo);
            $slider->photo = 0;
            $slider->save();

            return response()->json(['success' => true]);
        }

        return response()->json(['success' => false], 400);
    }
}
