<?php

namespace App\Http\Controllers\Admin;

use App\Helper\ImageHelper;
use App\Http\Controllers\Controller;
use App\Models\Team;
use Illuminate\Http\Request;

class TeamController extends Controller
{
    public $resource = 'team';
    public $route = 'teams';

    public function __construct()
    {
        view()->share('item', $this->resource);
        view()->share('route', $this->route);
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function index()
    {
        $teams = Team::query()->orderBy('created_at', 'desc')->paginate(10);
        return view('admin.crud.team._table',compact('teams'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function create()
    {
        return view('admin.crud.team._create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function store(Request $request)
    {
        $input = $request->all();
        if($request->hasFile('photo')  ) {
            $teamPhoto = ImageHelper::add($request->photo, null, 'photo');
            $input['photo'] = $teamPhoto;
            Team::query()->create($input);
        }
        return redirect()->route('dashboard.teams.index')->with('success', 'Team added successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $team = Team::query()->find($id);
        return view('admin.crud.team._edit',compact('team'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $team = Team::query()->find($id);
        $input = $request->all();
        if($request->hasFile('photo')  ) {
            $teamPhoto = ImageHelper::add($request->photo, null, 'photo');
            $input['photo'] = $teamPhoto;
        }
        $team->update($input);
        return redirect()->route('dashboard.teams.index')->with('Team updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\RedirectResponse
     */
    public function destroy($id)
    {
        Team::query()->where('id',$id)->first()->delete();
        return redirect()->route('dashboard.teams.index')->with('Team deleted successfully');
    }

    public function deleteImage(Request $request)
    {
        $team = Team::query()->findOrFail($request->team_id);

        // Delete the existing identity photo
        if ($team->photo) {
            ImageHelper::delete($team->photo);
            $team->photo = 0;
            $team->save();

            return response()->json(['success' => true]);
        }

        return response()->json(['success' => false], 400);
    }
}
