<?php

use App\Http\Controllers\Admin\AdminController;
use App\Http\Controllers\Admin\AuthController;
use App\Http\Controllers\Admin\BrandController;
use App\Http\Controllers\Admin\BrandHomeController;
use App\Http\Controllers\Admin\CategoryController;
use App\Http\Controllers\Admin\ContactController;
use App\Http\Controllers\Admin\CounterController;
use App\Http\Controllers\Admin\MainPageServiceController;
use App\Http\Controllers\Admin\MetaController;
use App\Http\Controllers\Admin\NewEventController;
use App\Http\Controllers\Admin\ProcessController;
use App\Http\Controllers\Admin\ProductController;
use App\Http\Controllers\Admin\ServiceController;
use App\Http\Controllers\Admin\SettingController;
use App\Http\Controllers\Admin\SliderController;
use App\Http\Controllers\Admin\SubCategoryController;
use App\Http\Controllers\Admin\TeamController;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Facades\Route;
use Mcamara\LaravelLocalization\Facades\LaravelLocalization;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

//Route::get('/', function () {
//    return view('welcome');
//});

## Admin routs
Route::get('/admin_login', [AuthController::class, 'loginView'])->name('admin_login');
Route::post('/login', [AuthController::class, 'login'])->name('login');

Route::group(['prefix' => 'arabia_mobiles', 'as' => 'arabiaMobiles.'], function () {
    require_once base_path('routes/front.php');
});

Route::group(['prefix' => 'dashboard','as' => 'dashboard.'], function () {


        Route::get('/analyses', [AuthController::class,'analyses'])->name('analyses');
        Route::group(['middleware' => 'auth:admin,employee'], function () {
            Route::get('/analyses', [AuthController::class, 'analyses'])->name('analyses');
            Route::get('/employee', [AuthController::class, 'employeeDashboard'])->name('employee');

            Route::get('/logout', [AuthController::class, 'logout'])->name('logout');
        });
        // new CRUDs
        Route::group(['middleware' => 'auth:admin'], function () {
            Route::resource('admins', AdminController::class);
            Route::resource('sliders', SliderController::class);
            Route::resource('process', ProcessController::class);
            Route::post('sliders/photo', [SliderController::class ,'deleteSliderPhoto'])->name('sliders.photo');

            Route::resource('mainPageServices', MainPageServiceController::class);
            Route::post('mainPageServices/deleteImage',  [MainPageServiceController::class ,'deleteImage'])->name('mainPageServices.deleteImage');

            Route::resource('services', ServiceController::class);
            Route::post('services/deleteImage',  [ServiceController::class ,'deleteImage'])->name('services.deleteImage');

            Route::resource('categories', CategoryController::class);
            Route::resource('subcategories',SubCategoryController::class);

            Route::resource('products',ProductController::class);
            Route::post('products/deleteImage',  [ProductController::class ,'deleteImage'])->name('products.deleteImage');

            Route::resource('brands',BrandController::class);

            Route::resource('newsEvents', NewEventController::class);
            Route::post('newsEvents/deleteImage',  [NewEventController::class ,'deleteImage'])->name('newsEvents.deleteImage');

            Route::resource('homeBrands', BrandHomeController::class);
            Route::post('homeBrands/photo', [BrandHomeController::class ,'deleteImage'])->name('homeBrands.photo');

            Route::resource('teams', TeamController::class);
            Route::post('teams/photo', [TeamController::class ,'deleteImage'])->name('teams.deleteImage');

            Route::resource('counters', CounterController::class);
            Route::post('counters/deleteImage',  [CounterController::class ,'deleteImage'])->name('counters.deleteImage');

            Route::resource('contacts', ContactController::class);
//            Route::resource('settings', SettingController::class);

            Route::get('settings/edit',[SettingController::class , 'edit'])->name('settings.edit');
            Route::put('settings/update/{id}',[SettingController::class , 'update'])->name('settings.update');
            Route::post('settings/deleteImage',  [SettingController::class ,'deleteImage'])->name('settings.deleteImage');

        });

        ## Setting
        Route::resource('metas', MetaController::class);
        ## general seo Routes
        Route::get('get_general_seo', [MetaController::class, 'getSeo'])->name('general_seo.index');
        Route::post('update_general_seo', [MetaController::class, 'updateSeo'])->name('general_seo.update');


});


Route::group(['middleware'=>['localizationRedirect', 'localeViewPath' ,'localeCookieRedirect','localeSessionRedirect'],'prefix' => LaravelLocalization::setLocale()],function ()
{
    Route::group(['middleware'=>'language'],function ()
    {
        Route::get('/', function () {
            return view('welcome');
        });
    });
});

Route::get('/xclear', function() {
    Artisan::call('config:cache');
    Artisan::call('cache:clear');
    Artisan::call('view:clear');
    Artisan::call('view:cache');
    Artisan::call('optimize:clear');
    Artisan::call('route:cache');
    return 'cleared';
});
